@@ -6,7 +6,7 @@ from gevent.server import StreamServer
 import kola
 from kola import safe_call, safe_func
 from .connection import Connection
-from .stream import GStream
+from .stream import Stream
 
 
 class Kola(kola.Kola):
@@ -19,7 +19,7 @@ class Kola(kola.Kola):
         self.conn_class = conn_class or Connection
 
     def handle_stream(self, sock, address):
-        self.conn_class(self, GStream(sock), address).process()
+        self.conn_class(self, Stream(sock), address).process()
 
     def run(self, host, port, patch_all=True):
         if patch_all:
