@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import time
 import gevent
-from kola.utils import safe_call
+from kola import safe_call
 
 
 class Later(object):
