@@ -45,7 +45,7 @@ class Stream(object):
         用shutdown可以直接触发. how: 0: SHUT_RD, 1: SHUT_WR, else: all
         shutdown后还是会触发close事件以及相关的回调函数，不必担心
         """
-        if not self.sock:
+        if self.closed():
             return
         safe_call(self.sock.shutdown, how)
 
@@ -70,7 +70,7 @@ class Stream(object):
         写数据
         """
 
-        if not self.wfile:
+        if self.closed():
             return
 
         safe_call(self.wfile.write, data)
@@ -100,7 +100,7 @@ class Stream(object):
         接收一行消息
         """
 
-        if not self.rfile:
+        if self.closed():
             return
 
         # 异常也认为服务器断掉链接了，或者该断掉链接
